@@ -1,19 +1,32 @@
+/**
+ * Copyright 2017 Red Hat Inc.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License. You may obtain
+ * a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
+ */
+
 import when from 'when';
 
 import * as utils from '../../js/services/utils';
 import MistralApiService from '../../js/services/MistralApiService';
+import mockHistory from '../mocks/history';
 import { mockGetIntl } from './utils';
 import PlansActions from '../../js/actions/PlansActions';
+// hacky solution to be able to spy on named export function
+import * as PlansActionsModule from '../../js/actions/PlansActions';
 import SwiftApiService from '../../js/services/SwiftApiService';
+import storage from '../mocks/storage';
 
-
-// Use these to mock asynchronous functions which return a promise.
-// The promise will immediately resolve/reject with `data`.
-let createResolvingPromise = (data) => {
-  return () => {
-    return when.resolve(data);
-  };
-};
+window.localStorage = window.sessionStorage = storage;
 
 describe('PlansActions', () => {
   beforeEach(() => {
@@ -25,26 +38,27 @@ describe('PlansActions', () => {
       spyOn(PlansActions, 'updatePlanPending');
       spyOn(PlansActions, 'updatePlanSuccess');
       spyOn(PlansActions, 'fetchPlans');
-      // Mock the service call.
-      spyOn(PlansActions, '_uploadFilesToContainer').and.callFake(createResolvingPromise());
-      // Call the action creator and the resulting action.
-      // In this case, dispatch and getState are just empty placeHolders.
-      PlansActions.updatePlan('somecloud', {})(() => {}, () => {}, mockGetIntl);
-      // Call done with a minimal timeout.
-      setTimeout(() => { done(); }, 1);
+      spyOn(PlansActionsModule, 'uploadFilesToContainer').and.callFake(
+        when.resolve
+      );
+      spyOn(MistralApiService, 'runWorkflow').and.callFake(() =>
+        when.resolve({ state: 'SUCCESS' })
+      );
+
+      PlansActions.updatePlan('somecloud', {}, mockHistory)(
+        () => {},
+        () => {},
+        mockGetIntl
+      );
+
+      setTimeout(() => {
+        done();
+      }, 1);
     });
 
     it('dispatches updatePlanPending', () => {
       expect(PlansActions.updatePlanPending).toHaveBeenCalledWith('somecloud');
     });
-
-    it('dispatches updatePlanSuccess', () => {
-      expect(PlansActions.updatePlanSuccess).toHaveBeenCalledWith('somecloud');
-    });
-
-    it('dispatches fetchPlans', () => {
-      expect(PlansActions.fetchPlans).toHaveBeenCalled();
-    });
   });
 
   describe('createPlan', () => {
@@ -52,15 +66,20 @@ describe('PlansActions', () => {
       spyOn(PlansActions, 'createPlanPending');
       spyOn(PlansActions, 'createPlanSuccess');
       // Mock the service call.
-      spyOn(PlansActions, '_uploadFilesToContainer').and.callFake(createResolvingPromise());
-      spyOn(MistralApiService, 'runAction').and.callFake(createResolvingPromise());
-      spyOn(MistralApiService, 'runWorkflow')
-        .and.callFake(createResolvingPromise({ state: 'SUCCESS' }));
+      spyOn(PlansActionsModule, 'uploadFilesToContainer').and.callFake(
+        when.resolve
+      );
+      spyOn(MistralApiService, 'runAction').and.callFake(when.resolve);
+      spyOn(MistralApiService, 'runWorkflow').and.callFake(() =>
+        when.resolve({ state: 'SUCCESS' })
+      );
       // Call the action creator and the resulting action.
       // In this case, dispatch and getState are just empty placeHolders.
       PlansActions.createPlan('somecloud', {})(() => {}, () => {}, mockGetIntl);
       // Call done with a minimal timeout.
-      setTimeout(() => { done(); }, 1);
+      setTimeout(() => {
+        done();
+      }, 1);
     });
 
     it('dispatches createPlanPending', () => {
@@ -74,12 +93,18 @@ describe('PlansActions', () => {
       spyOn(PlansActions, 'deletePlanSuccess');
       spyOn(PlansActions, 'fetchPlans');
       // Mock the service call.
-      spyOn(MistralApiService, 'runAction').and.callFake(createResolvingPromise());
+      spyOn(MistralApiService, 'runAction').and.callFake(when.resolve);
       // Call the action creator and the resulting action.
       // In this case, dispatch and getState are just empty placeHolders.
-      PlansActions.deletePlan('somecloud')(() => {}, () => {}, mockGetIntl);
+      PlansActions.deletePlan('somecloud', mockHistory)(
+        () => {},
+        () => {},
+        mockGetIntl
+      );
       // Call done with a minimal timeout.
-      setTimeout(() => { done(); }, 1);
+      setTimeout(() => {
+        done();
+      }, 1);
     });
 
     it('dispatches deletePlanPending', () => {
@@ -95,23 +120,38 @@ describe('PlansActions', () => {
     });
   });
 
-  let apiResponse = {
-    output: '{ "result": [ "overcloud", "another-cloud" ] }'
-  };
+  let apiResponseMistral = ['overcloud', 'another-cloud'];
+
+  let apiResponseSwift = [
+    { responseText: `description: Default deployment plan\nname: overcloud` },
+    { responseText: `description: My custom plan\nname: another-cloud` }
+  ];
 
   describe('fetchPlans', () => {
     beforeEach(done => {
+      let swiftAlreadyCalled = false;
       spyOn(PlansActions, 'requestPlans');
       spyOn(PlansActions, 'receivePlans');
-      spyOn(MistralApiService, 'runAction').and.callFake(
-        createResolvingPromise(apiResponse)
+      spyOn(MistralApiService, 'runAction').and.callFake(() =>
+        when.resolve(apiResponseMistral)
       );
+      spyOn(SwiftApiService, 'getObject').and.callFake(() => {
+        if (swiftAlreadyCalled) {
+          return apiResponseSwift[1];
+        } else {
+          swiftAlreadyCalled = true;
+          return apiResponseSwift[0];
+        }
+      });
+
       // Mock the service call.
       // Call the action creator and the resulting action.
       // In this case, dispatch and getState are just empty placeHolders.
       PlansActions.fetchPlans()(() => {}, () => {});
       // Call done with a minimal timeout.
-      setTimeout(() => { done(); }, 1);
+      setTimeout(() => {
+        done();
+      }, 1);
     });
 
     it('dispatches requestPlans', () => {
@@ -119,9 +159,19 @@ describe('PlansActions', () => {
     });
 
     it('dispatches receivePlans', () => {
-      expect(PlansActions.receivePlans).toHaveBeenCalledWith([ 'overcloud', 'another-cloud' ]);
+      expect(PlansActions.receivePlans).toHaveBeenCalledWith([
+        {
+          name: 'overcloud',
+          title: undefined,
+          description: undefined
+        },
+        {
+          name: 'another-cloud',
+          title: undefined,
+          description: undefined
+        }
+      ]);
     });
-
   });
 
   describe('fetchPlan', () => {
@@ -131,11 +181,15 @@ describe('PlansActions', () => {
     ];
 
     beforeEach(done => {
-      spyOn(SwiftApiService, 'getContainer').and.callFake(createResolvingPromise(apiResponse));
+      spyOn(SwiftApiService, 'getContainer').and.callFake(() =>
+        when.resolve(apiResponse)
+      );
       spyOn(PlansActions, 'requestPlan');
       spyOn(PlansActions, 'receivePlan');
       PlansActions.fetchPlan('overcloud')(() => {}, () => {});
-      setTimeout(() => { done(); }, 1);
+      setTimeout(() => {
+        done();
+      }, 1);
     });
 
     it('dispatches requestPlan', () => {
@@ -148,6 +202,5 @@ describe('PlansActions', () => {
         'capabilities_map.yaml': { name: 'capabilities_map.yaml' }
       });
     });
-
   });
 });
