@@ -1,3 +1,19 @@
+/**
+ * Copyright 2017 Red Hat Inc.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License. You may obtain
+ * a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
+ */
+
 import { List, Map, OrderedMap } from 'immutable';
 
 import * as selectors from '../../js/selectors/validations';
@@ -6,7 +22,7 @@ import {
   ActiveFilter,
   FiltersInitialState
 } from '../../js/immutableRecords/filters';
-import { CurrentPlanState } from '../../js/immutableRecords/currentPlan';
+import { InitialPlanState, Plan } from '../../js/immutableRecords/plans';
 import {
   WorkflowExecution
 } from '../../js/immutableRecords/workflowExecutions';
@@ -16,9 +32,14 @@ describe(' validations selectors', () => {
   let state;
   beforeEach(() => {
     state = {
-      currentPlan: new CurrentPlanState({
-        conflict: undefined,
-        currentPlanName: 'overcloud'
+      plans: new InitialPlanState({
+        currentPlanName: 'overcloud',
+        plansLoaded: true,
+        all: Map({
+          overcloud: new Plan({
+            name: 'overcloud'
+          })
+        })
       }),
       filters: FiltersInitialState(),
       validations: Map({
@@ -202,4 +223,57 @@ describe(' validations selectors', () => {
       expect(filtered.get('check-network-gateway')).toBeDefined();
     });
   });
+
+  describe('getMostRecentPlanUpdate', () => {
+    it('returns 0 if there are no executions', () => {
+      const executions = Map({});
+      expect(
+        selectors.getMostRecentPlanUpdate(executions, 'overcloud')
+      ).toEqual(0);
+    });
+
+    it('returns 0 if there are no relevant executions', () => {
+      const executions = Map({
+        one: Map({
+          workflow_name: 'tripleo.baremetal.v1.introspect',
+          updated_at: 1504686886000
+        })
+      });
+      expect(
+        selectors.getMostRecentPlanUpdate(executions, 'overcloud')
+      ).toEqual(0);
+    });
+
+    it('returns the most recent update time', () => {
+      const executions = Map({
+        one: WorkflowExecution({
+          workflow_name: 'tripleo.baremetal.v1.introspect',
+          updated_at: 1500000000007
+        }),
+        two: WorkflowExecution({
+          workflow_name: 'tripleo.plan_management.v1.create_deployment_plan',
+          updated_at: 1500000000004,
+          input: Map({ container: 'overcloud' })
+        }),
+        three: WorkflowExecution({
+          workflow_name: 'tripleo.plan_management.v1.update_deployment_plan',
+          updated_at: 1500000000003,
+          input: Map({ container: 'overcloud' })
+        }),
+        four: WorkflowExecution({
+          workflow_name: 'tripleo.plan_management.v1.delete_deployment_plan',
+          updated_at: 1500000000006,
+          input: Map({ container: 'overcloud' })
+        }),
+        five: WorkflowExecution({
+          workflow_name: 'tripleo.plan_management.v1.update_deployment_plan',
+          updated_at: 1500000000005,
+          input: Map({ container: 'another-cloud' })
+        })
+      });
+      expect(
+        selectors.getMostRecentPlanUpdate(executions, 'overcloud')
+      ).toEqual(1500000000004);
+    });
+  });
 });
