@@ -25,13 +25,13 @@ import { Route } from 'react-router-dom';
 import { getFilterByName } from '../../selectors/filters';
 import { getFilteredNodes, nodesInProgress } from '../../selectors/nodes';
 import Loader from '../ui/Loader';
+import NodeDrives from './NodeDrives/NodeDrives';
 import NodesActions from '../../actions/NodesActions';
 import NodesListForm from './NodesListView/NodesListForm';
 import NodesListView from './NodesListView/NodesListView';
 import NodesToolbar from './NodesToolbar/NodesToolbar';
 import NodesTableView from './NodesTableView';
 import RegisterNodesDialog from './RegisterNodesDialog';
-import RolesActions from '../../actions/RolesActions';
 
 const messages = defineMessages({
   loadingNodes: {
@@ -55,13 +55,11 @@ const messages = defineMessages({
 class Nodes extends React.Component {
   componentDidMount() {
     this.props.fetchNodes();
-    this.props.fetchRoles(this.props.currentPlanName);
   }
 
   refreshResults(e) {
     e.preventDefault();
     this.props.fetchNodes();
-    this.props.fetchRoles(this.props.currentPlanName);
   }
 
   renderContentView() {
@@ -88,6 +86,7 @@ class Nodes extends React.Component {
               inline
             >
               <a
+                id="Nodes__refreshResultsLink"
                 className="link btn btn-link"
                 onClick={this.refreshResults.bind(this)}
               >
@@ -96,7 +95,11 @@ class Nodes extends React.Component {
               </a>
             </Loader>
             &nbsp;
-            <Link to="/nodes/register" className="btn btn-primary">
+            <Link
+              to="/nodes/register"
+              className="btn btn-primary"
+              id="Nodes__registerNodesLink"
+            >
               <span className="fa fa-plus" />&nbsp;
               <FormattedMessage {...messages.registerNodes} />
             </Link>
@@ -112,16 +115,15 @@ class Nodes extends React.Component {
           {this.renderContentView()}
         </Loader>
         <Route path="/nodes/register" component={RegisterNodesDialog} />
+        <Route path="/nodes/:nodeId/drives" component={NodeDrives} />
       </div>
     );
   }
 }
 Nodes.propTypes = {
   contentView: PropTypes.string.isRequired,
-  currentPlanName: PropTypes.string.isRequired,
   fetchNodeIntrospectionData: PropTypes.func.isRequired,
   fetchNodes: PropTypes.func.isRequired,
-  fetchRoles: PropTypes.func.isRequired,
   fetchingNodes: PropTypes.bool.isRequired,
   intl: PropTypes.object.isRequired,
   nodes: ImmutablePropTypes.map.isRequired,
@@ -134,7 +136,6 @@ const mapStateToProps = state => ({
     'contentView',
     'list'
   ),
-  currentPlanName: state.currentPlan.currentPlanName,
   fetchingNodes: state.nodes.get('isFetching'),
   nodes: getFilteredNodes(state),
   nodesInProgress: nodesInProgress(state),
@@ -144,9 +145,7 @@ const mapStateToProps = state => ({
 const mapDispatchToProps = dispatch => ({
   fetchNodes: () => dispatch(NodesActions.fetchNodes()),
   fetchNodeIntrospectionData: nodeId =>
-    dispatch(NodesActions.fetchNodeIntrospectionData(nodeId)),
-  fetchRoles: currentPlanName =>
-    dispatch(RolesActions.fetchRoles(currentPlanName))
+    dispatch(NodesActions.fetchNodeIntrospectionData(nodeId))
 });
 
 export default injectIntl(connect(mapStateToProps, mapDispatchToProps)(Nodes));
