@@ -1,5 +1,22 @@
+/**
+ * Copyright 2017 Red Hat Inc.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License. You may obtain
+ * a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
+ */
+
 import ImmutablePropTypes from 'react-immutable-proptypes';
 import { defineMessages, injectIntl } from 'react-intl';
+import PropTypes from 'prop-types';
 import React from 'react';
 
 import HorizontalInput from '../../ui/forms/HorizontalInput';
@@ -23,10 +40,12 @@ class DriverFields extends React.Component {
     let ip_regex =
       '^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9]' +
       '[0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$';
-    let fqdn_regex = '^(?!:\/\/)([a-zA-Z0-9]+\.)?[a-zA-Z0-9][a-zA-Z0-9-]+\.[a-zA-Z]{2,6}?$';
+    let fqdn_regex =
+      '^(?!:\/\/)([a-zA-Z0-9]+\.)?[a-zA-Z0-9][a-zA-Z0-9-]+\.[a-zA-Z]{2,6}?$';
 
     this.portRegex =
-      '^([0-9]{1,4}|[1-5][0-9]{4}|6[0-4][0-9]{3}' + '|65[0-4][0-9]{2}|655[0-2][0-9]|6553[0-5])$$';
+      '^([0-9]{1,4}|[1-5][0-9]{4}|6[0-4][0-9]{3}' +
+      '|65[0-4][0-9]{2}|655[0-2][0-9]|6553[0-5])$$';
 
     this.ipOrFqdnValidator = {
       matchRegexp: new RegExp(ip_regex + '|' + fqdn_regex)
@@ -56,7 +75,9 @@ class DriverFields extends React.Component {
           labelColumnClasses="col-sm-5"
           value={this.props.node.pm_port}
           validations={{ matchRegexp: new RegExp(this.portRegex) }}
-          validationError={this.props.intl.formatMessage(messages.portValidationMessage)}
+          validationError={this.props.intl.formatMessage(
+            messages.portValidationMessage
+          )}
         />
         <HorizontalInput
           name="pm_user"
@@ -79,12 +100,12 @@ class DriverFields extends React.Component {
   }
 }
 DriverFields.propTypes = {
-  addr_title: React.PropTypes.string.isRequired,
-  intl: React.PropTypes.object,
+  addr_title: PropTypes.string.isRequired,
+  intl: PropTypes.object,
   node: ImmutablePropTypes.record.isRequired,
-  port_title: React.PropTypes.string.isRequired,
-  pwd_title: React.PropTypes.string.isRequired,
-  user_title: React.PropTypes.string.isRequired
+  port_title: PropTypes.string.isRequired,
+  pwd_title: PropTypes.string.isRequired,
+  user_title: PropTypes.string.isRequired
 };
 
 export default injectIntl(DriverFields);
