@@ -1,13 +1,31 @@
+/**
+ * Copyright 2017 Red Hat Inc.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License. You may obtain
+ * a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
+ */
+
 import { connect } from 'react-redux';
 import { defineMessages, FormattedMessage, injectIntl } from 'react-intl';
 import Formsy from 'formsy-react';
 import { fromJS, is } from 'immutable';
 import ImmutablePropTypes from 'react-immutable-proptypes';
 import { isObjectLike, mapValues } from 'lodash';
+import { Link, Redirect, Route, Switch } from 'react-router-dom';
 import PropTypes from 'prop-types';
 import React from 'react';
-import { Link } from 'react-router';
 
+import { checkRunningDeployment } from '../utils/checkRunningDeploymentHOC';
+import { getCurrentPlanName } from '../../selectors/plans';
 import { getRole } from '../../selectors/roles';
 import { getRoleServices } from '../../selectors/parameters';
 import Loader from '../ui/Loader';
@@ -21,6 +39,9 @@ import {
 } from '../ui/ModalPanel';
 import NavTab from '../ui/NavTab';
 import ParametersActions from '../../actions/ParametersActions';
+import RoleNetworkConfig from './RoleNetworkConfig';
+import RoleParameters from './RoleParameters';
+import RoleServices from './RoleServices';
 
 const messages = defineMessages({
   networkConfiguration: {
@@ -58,7 +79,8 @@ class RoleDetail extends React.Component {
   }
 
   componentDidMount() {
-    this.props.fetchParameters(this.props.currentPlanName, '/deployment-plan');
+    const { currentPlanName } = this.props;
+    this.props.fetchParameters(currentPlanName, `/plans/${currentPlanName}`);
   }
 
   componentDidUpdate() {
@@ -118,30 +140,34 @@ class RoleDetail extends React.Component {
   }
 
   renderRoleTabs() {
-    if (this.props.rolesLoaded && this.props.parametersLoaded) {
+    const {
+      currentPlanName,
+      formErrors,
+      match: { params: urlParams },
+      parametersLoaded,
+      rolesLoaded
+    } = this.props;
+    if (rolesLoaded && parametersLoaded) {
       return (
         <div className="row">
           <ul className="nav nav-tabs">
             <NavTab
-              to={`/deployment-plan/roles/${this.props.params.roleIdentifier}/parameters`}
+              to={`/plans/${currentPlanName}/roles/${urlParams.roleIdentifier}/parameters`}
             >
               <FormattedMessage {...messages.parameters} />
             </NavTab>
             <NavTab
-              to={`/deployment-plan/roles/${this.props.params.roleIdentifier}/services`}
+              to={`/plans/${currentPlanName}/roles/${urlParams.roleIdentifier}/services`}
             >
               <FormattedMessage {...messages.services} />
             </NavTab>
             <NavTab
-              to={
-                `/deployment-plan/roles/${this.props.params.roleIdentifier}` +
-                  '/network-configuration'
-              }
+              to={`/plans/${currentPlanName}/roles/${urlParams.roleIdentifier}/network-configuration`}
             >
               <FormattedMessage {...messages.networkConfiguration} />
             </NavTab>
           </ul>
-          <ModalFormErrorList errors={this.props.formErrors.toJS()} />
+          <ModalFormErrorList errors={formErrors.toJS()} />
         </div>
       );
     }
@@ -150,6 +176,12 @@ class RoleDetail extends React.Component {
   render() {
     const dataLoaded = this.props.rolesLoaded && this.props.parametersLoaded;
     const roleName = this.props.role ? this.props.role.name : null;
+    const {
+      currentPlanName,
+      intl,
+      location,
+      match: { params: urlParams }
+    } = this.props;
 
     return (
       <Formsy.Form
@@ -163,7 +195,11 @@ class RoleDetail extends React.Component {
         <ModalPanelBackdrop />
         <ModalPanel>
           <ModalPanelHeader>
-            <Link to="/deployment-plan" type="button" className="close">
+            <Link
+              to={`/plans/${currentPlanName}`}
+              type="button"
+              className="close"
+            >
               <span aria-hidden="true" className="pficon pficon-close" />
             </Link>
             <h2 className="modal-title">
@@ -177,12 +213,27 @@ class RoleDetail extends React.Component {
           <ModalPanelBody>
             <Loader
               height={60}
-              content={this.props.intl.formatMessage(
-                messages.loadingParameters
-              )}
+              content={intl.formatMessage(messages.loadingParameters)}
               loaded={dataLoaded}
             >
-              {this.props.children}
+              <Switch location={location}>
+                <Route
+                  path="/plans/:planName/roles/:roleIdentifier/parameters"
+                  component={RoleParameters}
+                />
+                <Route
+                  path="/plans/:planName/roles/:roleIdentifier/services"
+                  component={RoleServices}
+                />
+                <Route
+                  path="/plans/:planName/roles/:roleIdentifier/network-configuration"
+                  component={RoleNetworkConfig}
+                />
+                <Redirect
+                  from="/plans/:planName/roles/:roleIdentifier"
+                  to={`/plans/${currentPlanName}/roles/${urlParams.roleIdentifier}/parameters`}
+                />
+              </Switch>
             </Loader>
           </ModalPanelBody>
           {dataLoaded
@@ -203,14 +254,14 @@ class RoleDetail extends React.Component {
 }
 RoleDetail.propTypes = {
   allParameters: ImmutablePropTypes.map.isRequired,
-  children: PropTypes.node,
   currentPlanName: PropTypes.string,
   fetchParameters: PropTypes.func,
   formErrors: ImmutablePropTypes.list,
   formFieldErrors: ImmutablePropTypes.map,
   intl: PropTypes.object,
+  location: PropTypes.object.isRequired,
+  match: PropTypes.object.isRequired,
   parametersLoaded: PropTypes.bool.isRequired,
-  params: PropTypes.object.isRequired,
   role: ImmutablePropTypes.record,
   rolesLoaded: PropTypes.bool.isRequired,
   updateParameters: PropTypes.func
@@ -218,13 +269,13 @@ RoleDetail.propTypes = {
 
 function mapStateToProps(state, props) {
   return {
-    currentPlanName: state.currentPlan.currentPlanName,
+    currentPlanName: getCurrentPlanName(state),
     formErrors: state.parameters.form.get('formErrors'),
     formFieldErrors: state.parameters.form.get('formFieldErrors'),
     allParameters: state.parameters.parameters,
     parametersLoaded: state.parameters.loaded,
-    role: getRole(state, props.params.roleIdentifier),
-    roleServices: getRoleServices(state, props.params.roleIdentifier),
+    role: getRole(state, props.match.params.roleIdentifier),
+    roleServices: getRoleServices(state, props.match.params.roleIdentifier),
     rolesLoaded: state.roles.get('loaded')
   };
 }
@@ -249,6 +300,6 @@ function mapDispatchToProps(dispatch) {
   };
 }
 
-export default injectIntl(
-  connect(mapStateToProps, mapDispatchToProps)(RoleDetail)
+export default checkRunningDeployment(
+  injectIntl(connect(mapStateToProps, mapDispatchToProps)(RoleDetail))
 );
